Package: SNPassoc
Version: 2.3.1
Date: 2026-04-13
Depends: R (>= 4.0.0)
Imports: mvtnorm, parallel, survival, tidyr, plyr, ggplot2, poisbinom,
        rms, methods
Suggests: testthat, knitr, rmarkdown, biomaRt, VariantAnnotation,
        GenomicRanges, IRanges, S4Vectors, org.Hs.eg.db,
        TxDb.Hsapiens.UCSC.hg19.knownGene
Title: SNPs-Based Whole Genome Association Studies
Authors@R: c( person(given = "Victor", family = "Moreno", role = "aut"),
              person(given = "Juan R", family = "Gonzalez", 
              email = "juanr.gonzalez@isglobal.org", role = c("aut"),
              comment = c(ORCID = "0000-0003-3267-2146")),
              person(given = "Dolors", family = "Pelegri", 
              email = "dolors.pelegri@isglobal.org", role = c("aut", "cre"),
              comment = c(ORCID = "0000-0002-5993-3003")))
Description: Functions to perform most of the common analysis in genome 
    association studies are implemented. These analyses include descriptive 
    statistics and exploratory analysis of missing values, calculation of 
    Hardy-Weinberg equilibrium, analysis of association based on generalized
    linear models (either for quantitative or binary traits), and analysis
    of multiple SNPs (haplotype and epistasis analysis). Permutation test 
    and related tests (sum statistic and truncated product) are also 
    implemented. Max-statistic and genetic risk-allele score exact 
    distributions are also possible to be estimated. The methods are 
    described in Gonzalez JR et al., 2007 <doi: 10.1093/bioinformatics/btm025>.
    This version includes internal copies of functions from the archived 'haplo.stats' 
    package to maintain functionality.
URL: https://github.com/isglobal-brge/SNPassoc
License: GPL (>= 2)
Encoding: UTF-8
VignetteBuilder: knitr
RoxygenNote: 7.2.2
NeedsCompilation: yes
Packaged: 2026-04-13 08:38:52 UTC; dpelegri
Author: Victor Moreno [aut],
  Juan R Gonzalez [aut] (ORCID: <https://orcid.org/0000-0003-3267-2146>),
  Dolors Pelegri [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-5993-3003>)
Maintainer: Dolors Pelegri <dolors.pelegri@isglobal.org>
Repository: CRAN
Date/Publication: 2026-04-13 10:10:09 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-04-13 12:32:27 UTC; unix
Archs: SNPassoc.so.dSYM
