
`scanWGassociation` <-
function (formula, data, model = c("all"), nperm, quantitative = is.quantitative(formula,  
    data), genotypingRate = 80)  
{
    warning("This function is obsolete due to some problems with gfotran compiler. \n
        Use 'WGassociation' function instead or send an e-mail to the maintainer \n
        for receiving a version including this function")
}


