\name{getNiceTable}
\alias{getNiceTable}
\title{Get Latex output}
\usage{
getNiceTable( x )
}
\arguments{
\item{x}{WGassociation object.}
}
\value{
The R output of specific association analyses exported into LaTeX 
}
\description{
Create Latex output from association analyses
}
